#!/bin/sh

function askYesOrNo
{
	REPLY=""
	while [ -z "$REPLY" ] ; do
		read -ep "$1 [y/n]: " REPLY
		case $REPLY in
			Y|y|yes ) return 0 ;;
			N|n|no ) return 1 ;;
			* ) REPLY=""
		esac	
	done
}

function editScript
{
	file=$1
	binary=`awk '/^__BINARY_START__/ { print NR; exit 0; }' $file`
	head -n $binary $file | \
		sed -e "s/.*SERVER_ADDRESS=.*/SERVER_ADDRESS=$address/g" \
		-e "s/.*SERVER_PORT=.*/SERVER_PORT=$port/g" \
		-e "s/.*FORCE_ADDRESS_PORT=.*/FORCE_ADDRESS_PORT=$force/g" \
		> ${file}.new
	mv $file ${file}.old
	tail +$((binary+1)) ${file}.old|cat ${file}.new - > $file
	rm -f ${file}.new
	rm -f ${file}.old
}

path=/opt/novell/messenger/software

# Check for root privileges
if [ $(id -u) -ne 0 ] ; then
	echo $"You must be root to run this script"
	exit 1
fi

if [ "x$1" == "x--silent" ] ; then
	if [ ! -z "$2" ] ; then
		address=$2
	fi

	if [ ! -z "$3" ] ; then
		port=$3
	fi

	if [ ! -z "$4" ] ; then
		force=$4
	fi
else
	echo $"This script will configure the Messenger client Linux install scripts."
	
	read -ep $"Enter path to the Messenger software directory [$path]: " REPLY
	if [ -n "$REPLY" ] ; then
		path=$REPLY
	fi
	
	read -ep $"Enter server address: " address
	read -ep $"Enter server port: " port
	
	if askYesOrNo $"Force clients to use this address and port (overwrite existing client settings)?" ; then
		force=Yes
	else
		force=No
	fi
fi

if [ -e  $path/client/linux/nvlmsgr.bin ] ; then
	editScript $path/client/linux/nvlmsgr.bin
else
	echo $"Could not find $path/client/linux/nvlmsgr.bin. Make sure that the software path is correct."
fi

if [ -e  $path/client/linux/nvlmsgr.bin ] ; then
	editScript $path/client/linux/withjre/nvlmsgr.bin
else
	echo $"Could not find $path/client/linux/withjre/nvlmsgr.bin. Make sure that the software path is correct."
fi

echo $"Done updating client install scripts."
