#!/bin/bash

MA_PIDFILE=/var/opt/novell/messenger/temp/nmma.pid
AA_PIDFILE=/var/opt/novell/messenger/temp/nmaa.pid
NDSCONF=/etc/nds.conf
STARTUP_DIR=/etc/opt/novell/messenger
STARTUP_MA=$STARTUP_DIR/strtup.ma
SCHERR_DIR=/var/opt/novell/log/messenger
SCHERR_FILE=${SCHERR_DIR}/nmschema.err
DEFOBJS=/opt/novell/messenger/bin/defobjs
TEXTDOMAIN=install
TEXTDOMAINDIR=/opt/novell/messenger/locale

ARGPREFIX='\(--\|-\|\/\)'

function readNDSConf
{
	local tag value server

    while read line ; do
		tag=${line%%=*}
		if [ -n "$tag" ] ; then
			value=${line#*=}
			case $tag in
				n4u.base.tree-name ) g_tree=$value ;;
				n4u.nds.server-context ) g_context=$(echo $value | tr . ,) ;;
				n4u.nds.server-name ) server=${value}Server ;;
			esac
		fi
    done

	if [ -z "$g_server" ] || [ "$g_server" = "Server" ] ; then
		g_server=$server
	fi

	if ! checkContext $g_context ; then
		g_context=''
	fi

} < $NDSCONF

function readStartupFile
{
	local value line i

	i=0
    while read line ; do
		if [ -n "$line" ] ; then
			value=${line#*=}
			if [ "$value" == "$line" ] || [ -z "$value" ] ; then
				value=${line#*-}
			fi

			if [ "$value" == "$line" ] ; then
				value=
			fi

			case $line in

				";"* )
					# Skip options that are commented out
					;;

				# We will prompt for these ones later, so they get their own variables
				[-/]home[-=]* | --home[-=]* ) g_mahome=$value ;;
				[-/]user[-=]* | --user[-=]* ) g_admin=$value ;;
				[-/]password[-=]* | --password[-=]* ) g_pwd=$value ;;
				[-/]dirreplicaipaddr[-=]* | --dirreplicaipaddr[-=]* ) g_replica=$value ;;
				[-/]ldapipaddr[-=]* | --ldapipaddr[-=]* ) g_ldapipaddr=$value ;;
				[-/]ldapport[-=]* | --ldapport[-=]* ) g_ldapport=$value ;;
				[-/]ldapsslkey[-=]* | --ldapsslkey[-=]* ) g_ldapsslkey=$value ;;

				# Other settings that we won't be changing, but we don't want to lose
				# Keep their values in an array -- see editStartupFile
				* )
					if echo $line|grep -E "--[a-zA-Z]*.*" >/dev/null 2>&1 ||
						echo $line|grep -E "[-][a-zA-Z]*.*" >/dev/null 2>&1 ||
						echo $line|grep -E "[/][a-zA-Z]*.*" >/dev/null 2>&1 ; then
						g_lines[$i]=$line
						i=$((i+1))
					fi
					;;
			esac
		fi
    done
} < $STARTUP_MA

function backupStartupFile
{
	local n

    if [ -f $STARTUP_DIR/strtup.$1 ] ; then
		n=0
		while [ -f $STARTUP_DIR/strtup.$1.bak.$n ] ; do
			n=$((n + 1))
		done

		cp $STARTUP_DIR/strtup.$1 $STARTUP_DIR/strtup.$1.bak.$n
    fi
}

function editStartupFile
{
	local home line key value

	# Copy new startup in
	rm -f $STARTUP_DIR/strtup.$1
	cp $STARTUP_DIR/template/strtupen.$1 $STARTUP_DIR/strtup.$1

	case $1 in
		ma ) home=$g_mahome ;;
		aa ) home=$g_aahome ;;
	esac

	# Modify the startup with the basic stuff
    sed -e "s/.*${ARGPREFIX}home[-=].*/--home=$home/g" \
		-e "s/.*${ARGPREFIX}user[-=].*/--user=$g_admin/g" \
		-e "s/.*${ARGPREFIX}password[-=].*/--password=$g_pwd/g" \
		-e "s/.*${ARGPREFIX}dirreplicaipaddr[-=].*/--dirreplicaipaddr=$g_replica/g" \
		$STARTUP_DIR/strtup.$1 > $STARTUP_DIR/strtup.$1.new
    mv $STARTUP_DIR/strtup.$1.new $STARTUP_DIR/strtup.$1

	# Put ldap stuff in
	if [ -n "$g_ldapipaddr" ] ; then
		if [ -z "$g_ldapcert" ] ; then
			sed -e "s/.*${ARGPREFIX}ldapipaddr[-=].*/--ldapipaddr=$g_ldapipaddr/g" \
				-e "s/.*${ARGPREFIX}ldapport[-=].*/--ldapport=$g_ldapport/g" \
				-e "s/.*${ARGPREFIX}dirreplicaipaddr[-=]\(.*\)/;--dirreplicaipaddr=\2/g" \
				$STARTUP_DIR/strtup.$1 > $STARTUP_DIR/strtup.$1.new
			mv $STARTUP_DIR/strtup.$1.new $STARTUP_DIR/strtup.$1
		else
			sed -e "s/.*${ARGPREFIX}ldapipaddr[-=].*/--ldapipaddr=$g_ldapipaddr/g" \
				-e "s/.*${ARGPREFIX}ldapport[-=].*/--ldapport=$g_ldapport/g" \
				-e "s/.*${ARGPREFIX}ldapssl/--ldapssl/g" \
				-e "s/.*${ARGPREFIX}ldapsslkey[-=].*/--ldapsslkey=$(echo $g_ldapcert|sed -e "s/\//\\\\\//g")/g" \
				-e "s/.*${ARGPREFIX}dirreplicaipaddr[-=]\(.*\)/;--dirreplicaipaddr=\2/g" \
				$STARTUP_DIR/strtup.$1 > $STARTUP_DIR/strtup.$1.new
			mv $STARTUP_DIR/strtup.$1.new $STARTUP_DIR/strtup.$1
		fi
	fi

	# Add in other entries from old startup file
	for line in "${g_lines[@]}" ; do
		key=$(echo $line|sed -e "s/${ARGPREFIX}\([a-z]\+\).*/\2/g")
		if [ ! "$key" == "$line" ] ; then
			value=$(echo $line|sed -e "s/${ARGPREFIX}\([a-z]\+[-=]\)\(.*\)/\3/g")
			if [ "$value" == "$line" ] ; then
				value=
			fi
			if [ -n "$value" ] ; then
				sed -e "s/.*${ARGPREFIX}$key[-=].*/--$key=$(echo $value|sed -e "s/\//\\\\\//g")/g" \
					$STARTUP_DIR/strtup.$1 > $STARTUP_DIR/strtup.$1.new
				mv $STARTUP_DIR/strtup.$1.new $STARTUP_DIR/strtup.$1
			else
				sed -e "s/.*${ARGPREFIX}$key/--$key/g" \
					$STARTUP_DIR/strtup.$1 > $STARTUP_DIR/strtup.$1.new
				mv $STARTUP_DIR/strtup.$1.new $STARTUP_DIR/strtup.$1
			fi
		fi
	done

}

function setDefaultValues
{
	local pattern='^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+'
    g_system=MessengerService
    g_server=$(hostname -s)Server

    # Get default values
    if [ -f $NDSCONF ] ; then
		readNDSConf
    fi

    if [ -f $STARTUP_MA ] ; then
		readStartupFile
    fi

    # Parse $mahome to get defaults for system and server
    #if [ -n "$g_mahome" ] ; then
    #fi

	if [ -z "$g_ipaddr" ] ; then
		g_ipaddr=$(grep -m 1 -E "$pattern.*$(hostname -s).*" /etc/hosts|grep -o -E $pattern)

		# Make sure that it is not a loopback address
		if echo $g_ipaddr | grep -E "$127.*" > /dev/null 2>&1 ; then
			g_ipaddr=''
		fi
	fi

	if [ -z "$g_replica" ] ; then
		g_replica=$g_ipaddr
	fi
}

function checkContext
{
	local tmp n=1

	if [ -z "$1" ] ; then
		return 1
	fi

	# Are there commas?
	if ! echo $1|grep -E '.+,.+'  > /dev/null 2>&1 ; then
		if ! echo $1|grep -E '^[^=]+=[^=]+$' > /dev/null 2>&1 ; then
			return 1
		fi
	else
		# Break it up by commas and make sure that each one start with .*=
		tmp=$(echo $1|cut -f$n -d, -)
		while [ -n "$tmp" ] ; do
			if ! echo $tmp|grep -E '^[^=]+=[^=]+$' > /dev/null 2>&1 ; then
				return 1
			fi
			n=$((n + 1))
			tmp=$(echo $1|cut -f$n -d, -)

			# sanity check
			if [ $n -gt 100 ] ; then
				return 0
			fi
		done
	fi
	return 0
}

function promptForContextAndObjects
{
	newScreen
	local tree context

	while [ -z "$context" ] ; do
		read -ep $"Context to create the objects in, e.g. ou=org-unit,o=org [$g_context]: " REPLY
		if [ -n "$REPLY" ] ; then
			context=$REPLY
		else
			context=$g_context
		fi

		if [ -z "$context" ] ; then
			echo $"Error: you must enter a context."
		else
		  	#check to make sure that it is type and comma delimited
			if ! checkContext $context; then
				echo
				echo $"Error: context must be type and comma delimited, e.g. ou=org-unit,o=org."
				context=''
			fi
		fi

	done
	g_context=$context

    read -ep $"Messenger system object name [$g_system]: " REPLY
    if [ -n "$REPLY" ] ; then
		g_system=$REPLY
    fi

    read -ep $"Messenger server object name [$g_server]: " REPLY
    if [ -n "$REPLY" ] ; then
		g_server=$REPLY
    fi
}

function isEdirInstalled
{
	if [ -f /opt/novell/eDirectory/lib/libndssdk.so.1 ] ||  [ -f /usr/lib/libndssdk.so.1 ] ; then
		return 0
	fi
	return 1
}

function promptForDirectoryAccess
{
	local direct ldap ldapssl selection bldap ldapcert ldapipaddr

	newScreen

	if isEdirInstalled ; then
		ldap=$"Use LDAP to access eDirectory"
		direct=$"Use direct access"
		PS3=$"Choose directory access method: "
		select selection in  "$ldap" "$direct"; do
			if [ -n "$selection" ] ; then
				if [ "$selection" = "$direct" ] ; then
					bldap=0
					break
				elif [ "$selection" = "$ldap" ] ; then
					bldap=1
					break
				fi
			fi
		done
	else
		echo $"eDirectory is not installed on the local machine. Configuring agents to use LDAP."
		bldap=1
	fi

    if [ $bldap -eq 0 ] ; then
		while [ -z "$tree" ] ; do
			read -ep $"Name of eDirectory tree to extend and create objects in [$g_tree]: " REPLY
			if [ -n "$REPLY" ] ; then
				tree=$REPLY
			else
				tree=$g_tree
			fi

			if [ -z "$tree" ] ; then
				echo $"Error: you must enter a tree name."
			fi
		done
		g_tree=$tree

		read -ep $"Enter replica address for $g_tree [$g_replica]: " REPLY
		if [ -n "$REPLY" ] ; then
			g_replica=$REPLY
		fi
		g_ldapipaddr=''
    else
		g_tree=''
		while [ -z "$ldapipaddr" ] ; do
			read -ep $"Enter address of LDAP server [$g_ldapipaddr]: " REPLY
			if [ -n "$REPLY" ] ; then
				ldapipaddr=$REPLY
			else
				ldapipaddr=$g_ldapipaddr
			fi

			if [ -z "$ldapipaddr" ] ; then
				echo
				echo $"Error: you must enter an ip address for the LDAP server."
			fi
		done
		g_ldapipaddr=$ldapipaddr

		if askYesOrNo  $"Do you want to use SSL for LDAP connections?" ; then
		   	if [ -z "$g_ldapport" ] || [ "$g_ldapport" = 389 ] ; then
				g_ldapport=636
			fi

			read -ep $"LDAP port [$g_ldapport]: " REPLY
			if [ -n "$REPLY" ] ; then
				g_ldapport=$REPLY
			fi

			while [ -z "$ldapcert" ] ; do
				read -ep $"Enter the path to the LDAP server's root certificate [$g_ldapcert]: " REPLY
				if [ -n "$REPLY" ] ; then
					ldapcert=$REPLY
				else
					ldapcert=$g_ldapcert
				fi

				if [ -z "$ldapcert" ] ; then
					echo
					echo $"Error: You must enter a root certificate for LDAP SSL."
				elif [ ! -f $ldapcert ] ; then
					echo
					echo $"Error: regular file $ldapcert does not exist."
					echo $"Check to make sure the certificate has been exported and the path is correct."
					ldapcert=''
				fi
			done
			g_ldapcert=$ldapcert
		else
			if [ -z "$g_ldapport" ] || [ "$g_ldapport" = 636 ] ; then
				g_ldapport=389
			fi

			read -ep $"LDAP port [$g_ldapport]: " REPLY
			if [ -n "$REPLY" ] ; then
				g_ldapport=$REPLY
			fi
		fi

    fi
}

function promptForUserAndPassword
{
	local done admin

	newScreen

	if [ -z "$g_admin" ] ; then
		if checkContext $g_context ; then
			g_admin="cn=admin,$g_context"
		fi
	fi

	echo $"Enter the full context of the directory user object for the install to use."
	echo $"The object should have rights to extend the schema and create objects."
	echo $"The object will also be used by the Messenger agents to access the directory."
	echo $"NOTE: The specified object context must be typed and comma delimited."
	while [ -z "$admin" ] ; do
		read -ep "[$g_admin]: " REPLY
		if [ -n "$REPLY" ] ; then
			admin=$REPLY
		else
			admin=$g_admin
		fi

		if [ -n "$admin" ] ; then
			if ! checkContext $admin ; then
				echo
				echo $"Error: object DN must be typed and comma delimited, e.g. cn=admin,o=org."
				admin=''
			fi
		else
			echo
			echo $"Error: you must enter an object DN."
		fi
	done
	g_admin=$admin

    done=0
    while [ $done -eq 0 ] ; do
		read -esp $"Enter password: " REPLY
		echo
		read -esp $"Retype password: " REPLY2
		echo
		if [ "$REPLY" != "$REPLY2" ] ; then
			echo $"Passwords do not match! Try again..."  ; echo
		else
			g_pwd=$REPLY
			done=1
		fi
	done
}

function promptForInstallType
{
	local option1 option2 option3 selection

	newScreen

	option1=$"Create a new system"
	option2=$"Install a new server to an existing system"
	option3=$"Extend schema only"
    PS3=$"Selection: "
    select selection in "$option1" "$option2" "$option3" ; do
		case $selection in
			"$option1" )
				g_installtype=CREATE
				break
				;;
			"$option2" )
				g_installtype=SERVER
				break
				;;
			"$option3" )
				g_installtype=SCHEMA
				break
				;;
		esac
    done

}

function promptForConfiguration
{
	echo
	promptForDirectoryAccess

	echo
	promptForContextAndObjects

	echo
	promptForUserAndPassword

	echo
	promptForScope

	echo
	promptForIPAddr
}

function promptForScope
{
	newScreen

	# Default the scope to the default context
	if [ -z "$g_scope" ] ; then
		g_scope=$g_context;
	fi

	echo $"Enter the default context(s) to use to authenticate and search for users."
	echo $"Contexts must be typed, comma delimited, and separated by semi-colons."
	read -ep "[$g_scope]: " REPLY

	if [ -n "$REPLY" ] ; then
		g_scope=$REPLY
	fi
}

function promptForIPAddr
{
	newScreen

	echo $"Enter the network address that the Messenger agents will use."
	echo $"This should be the address of the local machine."
	read -ep "[$g_ipaddr]: " REPLY

	if [ -n "$REPLY" ] ; then
		g_ipaddr=$REPLY
	fi

#	reply -ep "Enter the port that the Messaging Agent will use [$g_maport]: " REPLY
#	reply -ep "Enter the port that the Archive Agent will use: [$g_aaport]:" REPLY
}

function askYesOrNo
{
	REPLY=""
	while [ -z "$REPLY" ] ; do
		read -ep "$1 $YES_NO_PROMPT" REPLY
		REPLY=$(echo ${REPLY}|tr [:lower:] [:upper:])
		case $REPLY in
			$YES_CAPS ) return 0 ;;
			$NO_CAPS ) return 1 ;;
			* ) REPLY=""
		esac
	done
}

function viewSummary
{
	local tmp

	newScreen

	echo $"           Summary"
	echo "---------------------------------"
	if [ -n "$g_tree" ] ; then
		echo $"Tree:             $g_tree"
	fi
	echo $"Context:          $g_context"
	echo $"System Object:    $g_system"
	echo $"Server Object:    $g_server"
	if [ -n "$g_ldapipaddr" ] ; then
		echo $"LDAP IP address:  $g_ldapipaddr"
		echo $"LDAP Port:        $g_ldapport"
		if [ -n "$g_ldapcert" ] ; then
			echo $"LDAP certificate: $g_ldapcert"
		fi
	else
		echo $"Replica address:  $g_replica"
	fi
	echo $"Directory user:   $g_admin"
	echo $"User contexts:    $g_scope"
	echo $"Agent IP address: $g_ipaddr"

	if 	! askYesOrNo $"Continue with installation?" ;	then
		exit 1
	fi
}

function doAllConfiguration
{
	echo

	g_mahome="cn=MessagingAgent,ou=$g_server,ou=$g_system,$g_context"
	g_aahome="cn=ArchiveAgent,ou=$g_server,ou=$g_system,$g_context"

	# Configuration
 	echo -n $"Creating startup files..."
    if [ -f $STARTUP_DIR/strtup.ma ] || [ -f $STARTUP_DIR/strtup.aa ] ; then
		backupStartupFile ma
		backupStartupFile aa
	fi

	editStartupFile ma
	editStartupFile aa
	echo $"Done."

	# Configure the Linux client installer with the address/port for the MA
	/opt/novell/messenger/configure-client-installer.sh --silent $g_ipaddr 8300 No > /dev/null 2>&1
}

function extendSchema
{
	local  directoryflags

	if [ -n "$g_ldapipaddr" ] ; then
		if [ -n "$g_ldapcert" ] ; then
			directoryflags="-r $g_ldapipaddr -l -f $g_ldapcert -t $g_ldapport"
		else
			directoryflags="-r $g_ldapipaddr -l -t $g_ldapport"
		fi
	else
		directoryflags="-r $g_replica"
	fi

	# Extend the schema
	echo
	echo -n $"Extending the schema..."
	mkdir -p $SCHERR_DIR
	$DEFOBJS $directoryflags -u "$g_admin" -p "$g_pwd" -e -d > "$SCHERR_FILE" 2>&1
	handleDefObjsError $?
}

function handleDefObjsError
{
	case $1 in
		0|1 )
			echo $"Done."
			return 0
			;;
		2 )
			echo $"Failed. Memory initialization error. Please contact Novell support."
			;;
		3 )
			echo $"Failed. Memory error. Please contact Novell support."
			;;
		4 )
			echo $"Failed. Invalid parameters sent to defobjs. Please contact Novell support."
			;;
		5 )
			echo $"Failed. Missing required parameters in call to defobjs. Please contact Novell support."
			;;
		6 )
			echo $"Failed. Error connecting or authenticating to the directory."
			echo $"Possible causes:"
			echo $"1. User $g_admin does not exists or the context is incorrect."
			echo $"2. Password for $g_admin was entered incorrectly."
			if [ -n "$g_ldapipaddr" ] ; then
				echo $"3. LDAP server address [$g_ldapipaddr] and/or port [$g_ldapport] are incorrect."
				if [ -z "$g_ldapcert" ] ; then
					echo $"4. Clear text passwords have not been enabled for the LDAP server."
				else
					echo $"4. The certificate [$g_ldapcert] is invalid."
				fi
			else
				echo $"3. Replica address [$g_replica] is incorrect."
			fi
			;;
		7 )
			echo $"Failed. Error creating/verifying objects."
			echo $"Possible causes:"
			echo $"1. User $g_admin does not have the appropriate rights to create objects in $g_context."
			echo $"2. Install failed to extend the schema."
			;;

		8 )
			echo $"Failed. See $SCHERR_FILE for details."
			;;
		9 )
			echo $"Failed. Invalid LDAP referral encountered."
			;;

		* )
			echo $"Failed. Unknown error. Please contact Novell support."
			;;
	esac
	return 1
}

function createDefaultSystem
{
	local  directoryflags

	if [ -n "$g_ldapipaddr" ] ; then
		if [ -n "$g_ldapcert" ] ; then
			directoryflags="-r $g_ldapipaddr -l -f $g_ldapcert -t $g_ldapport"
		else
			directoryflags="-r $g_ldapipaddr -l -t $g_ldapport"
		fi
	else
		directoryflags="-r $g_replica"
	fi

	# Extend the schema
	echo
	echo -n $"Extending the schema..."
	mkdir -p $SCHERR_DIR
	#echo $DEFOBJS $directoryflags -u "$g_admin" -p "$g_pwd" -e -d > "$SCHERR_FILE" 2>&1
	$DEFOBJS $directoryflags -u "$g_admin" -p "$g_pwd" -e -d > "$SCHERR_FILE" 2>&1
	if handleDefObjsError $? ; then

		# Create the objects
		echo
		echo -n $"Creating objects..."
		#echo $DEFOBJS $directoryflags -u "$g_admin" -p "$g_pwd" -s "ou=$g_system,$g_context" -n "$g_server" -c "$g_scope" -i "$g_ipaddr" -m -a
		$DEFOBJS $directoryflags -u "$g_admin" -p "$g_pwd" -s "ou=$g_system,$g_context" -n "$g_server" -c "$g_scope" -i "$g_ipaddr" -m -a
		if ! handleDefObjsError $? ; then
			return 1
		else
			return 0
		fi

	else
		return 1
	fi
}

function startService
{
	echo
	if askYesOrNo $"Do you want to start the agents now?" ; then

		if [ -f $MA_PIDFILE ] &&
			[ -n "$(ps -p $(cat $MA_PIDFILE) -o cmd --no-headers | grep $bindir/nmma)" ] ; then
				/etc/init.d/novell-nmma restart
		else
			/etc/init.d/novell-nmma start
		fi

		if [ -f $AA_PIDFILE ] &&
			[ -n "$(ps -p $(cat $AA_PIDFILE) -o cmd --no-headers | grep $bindir/nmaa)" ] ; then
				/etc/init.d/novell-nmaa restart
		else
			/etc/init.d/novell-nmaa start
		fi
	fi
}

function newScreen
{
	clear
#	echo
}

function showEULA
{
    echo $"The GroupWise Delano End User License Agreement will now be displayed."
    echo $"Please read the agreement carefully before accepting the terms."
    echo $"Press ENTER to continue."
    read
    echo ''
    more ./license.txt
    if ! askYesOrNo $"Do you accept all the terms of the preceding license agreement?" ; then
		echo $"Installation cannot proceed without acceptance of License Agreement."
		exit 1
    fi
}

########################################################
# Main script
########################################################

# Check for root privileges
if [ $(id -u) -ne 0 ] ; then
	echo $"You must be root to run this script"
	exit 1
fi

# Initialize the yes/no prompt
YES_STRING=$"y"
NO_STRING=$"n"
YES_NO_PROMPT=$"[y/n]: "
YES_CAPS=$(echo ${YES_STRING}|tr [:lower:] [:upper:])
NO_CAPS=$(echo ${NO_STRING}|tr [:lower:] [:upper:])

promptForInstallType

case $g_installtype in
	CREATE | SERVER )
		setDefaultValues
		promptForConfiguration
		viewSummary
		if ! createDefaultSystem ; then
			echo ; echo
			echo $"Could not create objects. Aborting install!"
			exit 1
		fi
		doAllConfiguration
		;;
	SCHEMA )
		promptForDirectoryAccess
		promptForUserAndPassword
		extendSchema
		;;
	* )
		echo $"Install type not supported."
		;;
esac

if [ $g_installtype = CREATE ] ||  [ $g_installtype = SERVER ] ; then
	startService
	echo
	echo  $"To start the Messaging Agent manually: /etc/init.d/novell-nmma start"
	echo  $"To start the Archive Agent manually:   /etc/init.d/novell-nmaa start"
	echo
fi
